@@ -6,9 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug::Attachment;
-$BZ::Client::Bug::Attachment::VERSION = '4.4001_003'; # TRIAL
-
-$BZ::Client::Bug::Attachment::VERSION = '4.4001003';use parent qw( BZ::Client::API );
+$BZ::Client::Bug::Attachment::VERSION = '4.4';
+use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html
 # These are in order as per the above
@@ -188,7 +187,7 @@ BZ::Client::Bug::Attachment - Client side representation of an Attachment to a B
 
 =head1 VERSION
 
-version 4.4001_003
+version 4.4
 
 =head1 SYNOPSIS
 
@@ -834,7 +833,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
