@@ -6,9 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::BugUserLastVisit;
-$BZ::Client::BugUserLastVisit::VERSION = '4.4001_003'; # TRIAL
+$BZ::Client::BugUserLastVisit::VERSION = '4.4';
 
-$BZ::Client::BugUserLastVisit::VERSION = '4.4001003';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/BugUserLastVisit.html
@@ -41,7 +40,7 @@ BZ::Client::BugUserLastVisit - Find and Store the last time a user visited a Bug
 
 =head1 VERSION
 
-version 4.4001_003
+version 4.4
 
 =head1 SYNOPSIS
 
@@ -128,10 +127,6 @@ I<last_visit_ts> (string) The timestamp the user last visited the bug.
 
 =back
 
-=head1 EXCEPTION HANDLING
-
-See L<BZ::Client::Exception>
-
 =head1 SEE ALSO
 
 L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/BugUserLastVisit.html>
@@ -152,7 +147,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
