@@ -6,9 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Classification;
-$BZ::Client::Classification::VERSION = '4.4001_003'; # TRIAL
+$BZ::Client::Classification::VERSION = '4.4';
 
-$BZ::Client::Classification::VERSION = '4.4001003';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Classificaton.html
@@ -36,7 +35,7 @@ BZ::Client::Classification - Client side representation of Classifications in Bu
 
 =head1 VERSION
 
-version 4.4001_003
+version 4.4
 
 =head1 SYNOPSIS
 
@@ -141,10 +140,6 @@ Classification is not enabled on this installation.
 
 =back
 
-=head1 EXCEPTION HANDLING
-
-See L<BZ::Client::Exception>
-
 =head1 SEE ALSO
 
 L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Classification.html>
@@ -165,7 +160,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
