@@ -6,9 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Component;
-$BZ::Client::Component::VERSION = '4.4001_003'; # TRIAL
+$BZ::Client::Component::VERSION = '4.4';
 
-$BZ::Client::Component::VERSION = '4.4001003';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Component.html
@@ -45,7 +44,7 @@ BZ::Client::Component - Client side representation of Product Components in Bugz
 
 =head1 VERSION
 
-version 4.4001_003
+version 4.4
 
 =head1 SYNOPSIS
 
@@ -350,10 +349,6 @@ bugs before trying to delete the component.
 
 =back
 
-=head1 EXCEPTION HANDLING
-
-See L<BZ::Client::Exception>
-
 =head1 SEE ALSO
 
 L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Component.html>
@@ -374,7 +369,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
