@@ -6,9 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Group;
-$BZ::Client::Group::VERSION = '4.4001_003'; # TRIAL
+$BZ::Client::Group::VERSION = '4.4';
 
-$BZ::Client::Group::VERSION = '4.4001003';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Group.html
@@ -45,7 +44,7 @@ BZ::Client::Group - The API for creating, changing, and getting info on Groups
 
 =head1 VERSION
 
-version 4.4001_003
+version 4.4
 
 =head1 SYNOPSIS
 
@@ -354,11 +353,7 @@ Logged-in users are not authorized to edit bugzilla groups as they are not membe
 
 =head1 INSTANCE METHODS
 
-FIXME Not yet implemented
-
-=head1 EXCEPTION HANDLING
-
-See L<BZ::Client::Exception>
+Not yet implemented
 
 =head1 SEE ALSO
 
@@ -380,7 +375,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
