@@ -7,9 +7,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Product;
-$BZ::Client::Product::VERSION = '4.4001_003'; # TRIAL
+$BZ::Client::Product::VERSION = '4.4';
 
-$BZ::Client::Product::VERSION = '4.4001003';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Product.html
@@ -222,7 +221,7 @@ BZ::Client::Product - Client side representation of a product in Bugzilla
 
 =head1 VERSION
 
-version 4.4001_003
+version 4.4
 
 =head1 SYNOPSIS
 
@@ -788,10 +787,6 @@ Added in Bugzilla 4.2 as a replacement for L</internals>.
 Returned by L</get> until version 4.2, at which point it was dropped.
 Remains for compatibility. Please move away from using it asap.
 
-=head1 EXCEPTION HANDLING
-
-See L<BZ::Client::Exception>
-
 =head1 SEE ALSO
 
 L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Product.html>
@@ -812,7 +807,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
