@@ -6,9 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC;
-$BZ::Client::XMLRPC::VERSION = '4.4001_003'; # TRIAL
+$BZ::Client::XMLRPC::VERSION = '4.4';
 
-$BZ::Client::XMLRPC::VERSION = '4.4001003';
 use URI;
 use Encode;
 use XML::Writer;
@@ -319,17 +318,15 @@ sub logDirectory {
 }
 
 package BZ::Client::XMLRPC::int;
-$BZ::Client::XMLRPC::int::VERSION = '4.4001_003'; # TRIAL
-
-$BZ::Client::XMLRPC::int::VERSION = '4.4001003';sub new {
+$BZ::Client::XMLRPC::int::VERSION = '4.4';
+sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
 }
 
 package BZ::Client::XMLRPC::boolean;
-$BZ::Client::XMLRPC::boolean::VERSION = '4.4001_003'; # TRIAL
-
-$BZ::Client::XMLRPC::boolean::VERSION = '4.4001003';sub new {
+$BZ::Client::XMLRPC::boolean::VERSION = '4.4';
+sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
 }
@@ -345,9 +342,8 @@ sub FALSE { $false }
 }
 
 package BZ::Client::XMLRPC::double;
-$BZ::Client::XMLRPC::double::VERSION = '4.4001_003'; # TRIAL
-
-$BZ::Client::XMLRPC::double::VERSION = '4.4001003';sub new {
+$BZ::Client::XMLRPC::double::VERSION = '4.4';
+sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
 }
@@ -366,7 +362,7 @@ BZ::Client::XMLRPC - Performs XML-RPC calls on behalf of the client.
 
 =head1 VERSION
 
-version 4.4001_003
+version 4.4
 
 =head1 SYNOPSIS
 
@@ -428,7 +424,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
