@@ -5,9 +5,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Handler;
-$BZ::Client::XMLRPC::Handler::VERSION = '4.4001_003'; # TRIAL
-
-$BZ::Client::XMLRPC::Handler::VERSION = '4.4001003';sub new {
+$BZ::Client::XMLRPC::Handler::VERSION = '4.4';
+sub new {
     my $class = shift;
     my $self = { @_ };
     $self->{'level'} = 0;
@@ -86,7 +85,7 @@ BZ::Client::XMLRPC::Handler - Abstract event handler for parsing an XML-RPC resp
 
 =head1 VERSION
 
-version 4.4001_003
+version 4.4
 
 =head1 AUTHORS
 
@@ -104,7 +103,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
