@@ -6,9 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Parser;
-$BZ::Client::XMLRPC::Parser::VERSION = '4.4001_003'; # TRIAL
-
-$BZ::Client::XMLRPC::Parser::VERSION = '4.4001003';use BZ::Client::XMLRPC::Response;
+$BZ::Client::XMLRPC::Parser::VERSION = '4.4';
+use BZ::Client::XMLRPC::Response;
 use BZ::Client::Exception;
 use XML::Parser ();
 
@@ -106,7 +105,7 @@ BZ::Client::XMLRPC::Parser - A parser for an XML-RPC response.
 
 =head1 VERSION
 
-version 4.4001_003
+version 4.4
 
 =head1 AUTHORS
 
@@ -124,7 +123,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
