@@ -6,9 +6,8 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Value;
-$BZ::Client::XMLRPC::Value::VERSION = '4.4001_003'; # TRIAL
-
-$BZ::Client::XMLRPC::Value::VERSION = '4.4001003';use parent qw( BZ::Client::XMLRPC::Handler );
+$BZ::Client::XMLRPC::Value::VERSION = '4.4';
+use parent qw( BZ::Client::XMLRPC::Handler );
 use BZ::Client::XMLRPC::Struct;
 use BZ::Client::XMLRPC::Array;
 use DateTime::Format::ISO8601 ();
@@ -137,7 +136,7 @@ BZ::Client::XMLRPC::Value - Event handler for parsing a single XML-RPC value.
 
 =head1 VERSION
 
-version 4.4001_003
+version 4.4
 
 =head1 AUTHORS
 
@@ -155,7 +154,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dean Hamstad.
+This software is copyright (c) 2016 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
